
# Slot: code_set


the identifier of an enumeration code set.

URI: [linkml:code_set](https://w3id.org/linkml/code_set)


## Domain and Range

enum_definition &#8594;  <sub>0..1</sub> uriorcurie

## Parents


## Children


## Used by

 * enum_definition
